@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-use version; our $VERSION = 'v0.9.2';
+use version; our $VERSION = 'v0.9.3';
 
 our @COMMANDS_INFO = (
     +{
@@ -76,6 +76,10 @@ Description:
     See "\h detaildump"
 EODESC
     },
+    +{
+        command => 'dump_all',
+        summary => 'Dump whole server data',
+    },
     +{
         command => 'randomset',
         summary => 'Generate sample data and SET them',
